@@ -1,6 +1,6 @@
 package IRC::Mode::Set;
 {
-  $IRC::Mode::Set::VERSION = '0.080000';
+  $IRC::Mode::Set::VERSION = '0.081000';
 }
 
 use 5.10.1;
@@ -79,6 +79,7 @@ sub _build_params {
   $arr
 }
 
+sub as_string { $_[0]->mode_string }
 has mode_string => (
   lazy      => 1,
   is        => 'ro',
@@ -329,6 +330,11 @@ L</mode_array>.
 
 Returns the string representing the mode change.
 
+=head2 as_string
+
+B<as_string> is an alias for B<mode_string> to retain compatibility with
+L<IRC::Mode::Single>.
+
 =head2 params
 
 Retrieve only the parameters to the mode change (as an ARRAY)
