@@ -1,6 +1,6 @@
 package IRC::Toolkit::ISupport;
 {
-  $IRC::Toolkit::ISupport::VERSION = '0.080000';
+  $IRC::Toolkit::ISupport::VERSION = '0.081000';
 }
 use 5.10.1;
 use Carp 'confess';
@@ -170,10 +170,20 @@ sub parse_isupport {
     my ($cls, %self) = @_;
     bless +{%self}, $cls 
   }
+
   sub list    { $_[0]->{list} }
   sub always  { $_[0]->{always} }
   sub whenset { $_[0]->{whenset} }
   sub bool    { $_[0]->{bool} }
+
+  sub as_string {
+    my ($self) = @_;
+    join ',', map { join '', @$_ }
+      $self->list,
+      $self->always,
+      $self->whenset,
+      $self->bool
+  }
 }
 
 { package
@@ -184,8 +194,14 @@ sub parse_isupport {
     my ($cls, %self) = @_;
     bless +{%self}, $cls
   }
+
   sub prefix { $_[0]->{prefix} }
   sub flags  { $_[0]->{flags}  }
+
+  sub as_string {
+    my ($self) = @_;
+    join ',', $self->prefix, join '', @{ $self->flags }
+  }
 }
 
 { package
@@ -314,6 +330,10 @@ You can retrieve ARRAYs containing lists of modes belonging to each set:
   my $whenset = $isupport->chanmodes->whenset;
   my $boolean = $isupport->chanmodes->bool;
 
+Or retrieve the full string representation via B<as_string>:
+
+  my $chanmodes = $isupport->chanmodes->as_string;
+
 =head3 chantypes
 
 Without any arguments, returns a HASH whose keys are the allowable channel
@@ -331,12 +351,14 @@ With a token specified, returns boolean true if the token is enabled.
 
 =head3 extban
 
-Returns an object with two methods:
+Returns an object with the following methods:
 
 B<prefix> returns the extended ban prefix character.
 
 B<flags> returns the supported extended ban flags as an ARRAY of flags.
 
+B<as_string> returns the string representation of the EXTBAN= declaration.
+
 =head3 maxlist
 
 Without any arguments, returns a HASH mapping list-type modes (see
